@@ -522,7 +522,7 @@ class ChainlitAdapter(SDKAdapter):
         
         return tool_calls
 
-    async def process_tool_calls(self, is_sequence_agent: bool, sequence_agent_graph_items:List[GraphItem], reported_sequence_sub_agent_ids: set, run_id: str, tool_calls: Dict[int, ChainlitToolCallWithLLMResponse], on_node_enter: Optional[Callable], on_node_error: Optional[Callable], agent_custom_functions: list[GraphItem] = [], local_tools: Dict[str, Callable] = None) -> str | None:
+    async def process_tool_calls(self,run_id: str, tool_calls: Dict[int, ChainlitToolCallWithLLMResponse], is_sequence_agent: bool = False, sequence_agent_graph_items:List[GraphItem] = [], reported_sequence_sub_agent_ids: set = set(), on_node_enter: Optional[Callable] = None, on_node_error: Optional[Callable] = None, agent_custom_functions: list[GraphItem] = [], local_tools: Dict[str, Callable] = None) -> str | None:
         """
         Process tool calls by formatting their payloads and executing them.
 
@@ -589,7 +589,7 @@ class ChainlitAdapter(SDKAdapter):
         if is_sequence_agent and not self.agent.id in reported_sequence_sub_agent_ids:
             reported_sequence_sub_agent_ids.add(self.agent.id)
             sub_agent_graph_item = next((gi for gi in sequence_agent_graph_items if gi.item_id == self.agent.id),None)
-            if sub_agent_graph_item:
+            if sub_agent_graph_item and on_node_enter:
                 await on_node_enter(tool_call=ToolCall(name=self.agent.name,type=ToolCallType.XPANDER),graph_item=sub_agent_graph_item)
             # sleep for animation to work
             await wait(seconds=1)
@@ -727,7 +727,8 @@ class ChainlitAdapter(SDKAdapter):
             
             if not tool_call_result.is_success and is_debug_mode_active:
                 current_step.is_error = True
-                await on_node_error(tool_call_result=tool_call_result,graph_item=graph_item)
+                if on_node_error:
+                    await on_node_error(tool_call_result=tool_call_result,graph_item=graph_item)
             
             if not execution_id in self.execution_tool_calls:
                 self.execution_tool_calls[execution_id] = [tool_call_result.function_name]
